/*
  diskio.h

  Header file for disk I/O operations.

  MAT 4970
  Bill Slough
*/

#ifndef DISKIO_H
#define DISKIO_H

/* Number of bytes per sector */
#define BLOCKSIZE 512

/* Sector limits */
#define MINSECTOR 0
#define MAXSECTOR 2879

/* Read a sector from the disk */
int DisketteRead(char * filename, unsigned int sector, char * buffer);

/* Write a sector to the disk */
int DisketteWrite(char * filename, unsigned int sector, char * buffer);

/* Display one sector */
void DisplaySector(char * values);

#endif
