/*
  sdump.c

  Read and display the boot sector of a 1.44 Mb diskette image file.
  
  MAT 4970
  Bill Slough
*/

#include "diskio.h"
#include <stdlib.h>

int main() {
    /* Read and display the boot sector */
    char buffer[BLOCKSIZE];
    int result = DisketteRead("floppy-image", 0, buffer);
    if (result != -1) {
	DisplaySector(buffer);
        exit(0);
    }
    else
	exit(1);
}
